/*
  simple control gui for a YafDecoder
  Copyright (C) 1998  Martin Vogt

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation.

  For more information look at the file COPYRIGHT in this package

 */



#include <deviceWidgets/guiDecoder.h>



GuiDecoder::GuiDecoder( QWidget *parent=0, 
			const char *name=0 ) : GuiDevice (parent,name) {
  producer=NULL;
}


GuiDecoder::~GuiDecoder() {

}


void GuiDecoder::play() {
  if (producer != NULL) {
    producer->play();
  }
}


void GuiDecoder::pause() {
  if (producer != NULL) {
    producer->pause();
  }
}


void GuiDecoder::stop() {
  if (producer != NULL) {
    producer->close();
  }
}


void GuiDecoder::setDevice(GenericStreamProducer* device) {
  if (producer != NULL) {
    disconnect(playButton,0,this,0);
    disconnect(pauseButton,0,this,0);
    disconnect(stopButton,0,this,0);
    
  }
  producer=device;

  if (producer != NULL) {
    connect( playButton, SIGNAL(clicked()), this, SLOT(play()) );
    connect( pauseButton, SIGNAL(clicked()), this, SLOT(pause()) );
    connect( stopButton, SIGNAL(clicked()), this, SLOT(stop()) );
  }
  GuiDevice::setDevice(device);

}




void GuiDecoder::buildGui () {
  layout = new QBoxLayout( this, QBoxLayout:: LeftToRight, 5 );
  // fill the leftmost vertical box  
  playButton = new QPushButton( this, "play button 1" );  
  playButton->setText( "Play" );  
  playButton->setMinimumSize( playButton->sizeHint() );  
  playButton->setMaximumSize( playButton->sizeHint() );
  layout->addWidget( playButton, AlignLeft|AlignTop );  


  pauseButton = new QPushButton( this, "rb2" ); 
  pauseButton->setText( "Pause" );  
  pauseButton->setMinimumSize( pauseButton->sizeHint() ); 
  pauseButton->setMaximumSize( pauseButton->sizeHint() );
  layout->addWidget( pauseButton );  

  stopButton = new QPushButton( this, "rb3" ); 
  stopButton->setText( "Stop" );  
  stopButton->setMinimumSize( stopButton->sizeHint() ); 
  stopButton->setMaximumSize( stopButton->sizeHint() );
  layout->addWidget( stopButton );  

  
}
 




